<?php
/**
 * Custom Functions.
 *
 * @package SocialLive
 */

if( !function_exists( 'sociallive_fonts_url' ) ) :

    //Google Fonts URL
    function sociallive_fonts_url(){

        $font_families = array(
            'Roboto:wght@100;300;400;500;700;900',
        );

        $fonts_url = add_query_arg( array(
            'family' => implode( '&family=', $font_families ),
            'display' => 'swap',
        ), 'https://fonts.googleapis.com/css2' );

        return esc_url_raw($fonts_url);

    }

endif;

if( !function_exists( 'sociallive_video_pop_up_url' ) ) :

    function sociallive_video_pop_up_url( $content, $video ,$video_url) {
        // Only get video from the content if a playlist isn't present.
        if ( false === strpos( $content, 'wp-playlist-script' ) ) {
            $video = get_media_embedded_in_content( $content, array( 'video', 'object', 'embed', 'iframe' ) );
        }

        if (!empty($video)) {
            // find all iframes generated by php or that are in html    
            preg_match_all('/<iframe[^>]+src="([^"]+)"/', $video[0], $match);

            $urls = $match[1];
            if (empty($urls[0])) {
               preg_match_all('/<video[^>]+src="([^"]+)"/', $video[0], $match);
               $urls = $match[1];
               $video_url = $urls[0];
            } else {
                $video_url = strstr($urls[0], '?', true) ?: $urls[0];
            }
        }

        return $video_url;
    }
    
endif;

if (!function_exists('sociallive_iframe_escape')) :

    /** Escape Iframe **/
    function sociallive_iframe_escape($input)
    {

        $all_tags = array(
            'iframe' => array(
                'width' => array(),
                'height' => array(),
                'src' => array(),
                'frameborder' => array(),
                'allow' => array(),
                'allowfullscreen' => array(),
            ),
            'video' => array(
                'width' => array(),
                'height' => array(),
                'src' => array(),
                'style' => array(),
                'controls' => array(),
            )
        );

        return wp_kses($input, $all_tags);

    }

endif;

if( !function_exists('sociallive_read_more_render') ):

    function sociallive_read_more_render(){ ?>
<div class="entry-meta">
    <div class="entry-meta-link">
        <a href="<?php the_permalink(); ?>">
            <?php esc_html_e('Read More','sociallive'); ?>
        </a>
    </div>
</div>

<?php
    }

endif;

if( !function_exists( 'sociallive_social_menu_icon' ) ) :

    function sociallive_social_menu_icon( $item_output, $item, $depth, $args ) {

        // Add Icon
        if ( 'sociallive-social-menu' === $args->theme_location ) {

            $svg = SocialLive_SVG_Icons::get_theme_svg_name( $item->url );

            if ( empty( $svg ) ) {
                $svg = sociallive_the_theme_svg( 'link',$return = true );
            }

            $item_output = str_replace( $args->link_after, '</span>' . $svg, $item_output );
        }

        return $item_output;
    }
    
endif;

add_filter( 'walker_nav_menu_start_el', 'sociallive_social_menu_icon', 10, 4 );

if( !function_exists( 'sociallive_add_sub_toggles_to_main_menu' ) ) :

    function sociallive_add_sub_toggles_to_main_menu( $args, $item, $depth ) {

        // Add sub menu toggles to the Expanded Menu with toggles.
        if( isset( $args->show_toggles ) && $args->show_toggles ){

            // Wrap the menu item link contents in a div, used for positioning.
            $args->before = '<div class="submenu-wrapper">';
            $args->after  = '';

            // Add a toggle to items with children.
            if( in_array( 'menu-item-has-children', $item->classes, true ) ){

                $toggle_target_string = '.menu-item.menu-item-' . $item->ID . ' > .sub-menu';
                // Add the sub menu toggle.
                $args->after .= '<button class="toggle submenu-toggle" data-toggle-target="' . $toggle_target_string . '" data-toggle-type="slidetoggle" data-toggle-duration="250" aria-expanded="false"><span class="btn__content" tabindex="-1"><span class="screen-reader-text">' . __( 'Show sub menu', 'sociallive' ) . '</span>' . sociallive_the_theme_svg( 'chevron-down',$return = true ) . '</span></button>';

            }

            // Close the wrapper.
            $args->after .= '</div><!-- .submenu-wrapper -->';

            // Add sub menu icons to the primary menu without toggles.
        }elseif( 'sociallive-primary-menu' === $args->theme_location ){

            if( in_array( 'menu-item-has-children', $item->classes, true ) ){

                $args->after = '<span class="icon">'.sociallive_the_theme_svg('chevron-down',true).'</span>';

            }else{

                $args->after = '';

            }
        }

        return $args;

    }

endif;

add_filter( 'nav_menu_item_args', 'sociallive_add_sub_toggles_to_main_menu', 10, 3 );


/**
 * SocialLive SVG Icon helper functions
 *
 * @package SocialLive
 * @since 1.0.0
 */
if ( ! function_exists( 'sociallive_the_theme_svg' ) ):
    /**
     * Output and Get Theme SVG.
     * Output and get the SVG markup for an icon in the SocialLive_SVG_Icons class.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function sociallive_the_theme_svg( $svg_name, $return = false ) {

        if( $return ){

            return sociallive_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in sociallive_get_theme_svg();.

        }else{

            echo sociallive_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in sociallive_get_theme_svg();.
            
        }
    }

endif;

if ( ! function_exists( 'sociallive_get_theme_svg' ) ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function sociallive_get_theme_svg( $svg_name ) {

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            SocialLive_SVG_Icons::get_svg( $svg_name ),
            array(
                'svg'     => array(
                    'class'       => true,
                    'xmlns'       => true,
                    'width'       => true,
                    'height'      => true,
                    'viewbox'     => true,
                    'aria-hidden' => true,
                    'role'        => true,
                    'focusable'   => true,
                    ' preserveAspectRatio' => true,
                ),
                'path'    => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'd'         => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'points'    => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );
        if ( ! $svg ) {
            return false;
        }
        return $svg;

    }

endif;


if( !function_exists( 'sociallive_post_category_list' ) ) :

    // Post Category List.
    function sociallive_post_category_list( $select_cat = true ){

        $post_cat_lists = get_categories(
            array(
                'hide_empty' => '0',
                'exclude' => '1',
            )
        );

        $post_cat_cat_array = array();
        if( $select_cat ){

            $post_cat_cat_array[''] = esc_html__( '-- Select Category --','sociallive' );

        }

        foreach ( $post_cat_lists as $post_cat_list ) {

            $post_cat_cat_array[$post_cat_list->slug] = $post_cat_list->name;

        }

        return $post_cat_cat_array;
    }

endif;

if( !function_exists('sociallive_sanitize_meta_pagination') ):

    /** Sanitize Enable Disable Checkbox **/
    function sociallive_sanitize_meta_pagination( $input ) {

        $valid_keys = array('global-layout','no-navigation','norma-navigation','ajax-next-post-load');
        if ( in_array( $input , $valid_keys ) ) {
            return $input;
        }
        return '';

    }

endif;

if ( ! function_exists( 'sociallive_header_toggle_search' ) ):

    /**
     * Header Search
     **/
    function sociallive_header_toggle_search() {

        $sociallive_default = sociallive_get_default_theme_options();
        $ed_header_search = get_theme_mod( 'ed_header_search', $sociallive_default['ed_header_search'] );        
        if( $ed_header_search ){ ?>

<div class="header-searchbar">
    <div class="header-searchbar-inner">
        <div class="wrapper">

            <div class="header-searchbar-area">

                <a href="javascript:void(0)" class="skip-link-search-start"></a>

                <?php get_search_form(); ?>

            </div>

            <button type="button" id="search-closer" class="exit-search">
                <?php sociallive_the_theme_svg('cross'); ?>
            </button>

            <a href="javascript:void(0)" class="skip-link-search-end"></a>

        </div>
    </div>
</div>

<?php
        }

    }

endif;

add_action( 'sociallive_before_footer_content_action','sociallive_header_toggle_search',10 );

if( !function_exists('sociallive_content_offcanvas') ):

    // Offcanvas Contents
    function sociallive_content_offcanvas(){ ?>

<div id="offcanvas-menu">
    <div class="offcanvas-wraper">

        <div class="close-offcanvas-menu">
            <div class="offcanvas-close">

                <a href="javascript:void(0)" class="skip-link-menu-start"></a>

                <button type="button" class="button-offcanvas-close">
                    <?php sociallive_the_theme_svg('close'); ?>
                </button>

            </div>
        </div>

        <div id="primary-nav-offcanvas" class="offcanvas-item offcanvas-main-navigation">
            <nav class="primary-menu-wrapper" aria-label="<?php esc_attr_e('Horizontal', 'sociallive'); ?>"
                role="navigation">
                <ul class="primary-menu">

                    <?php
                            if( has_nav_menu('sociallive-primary-menu') ){

                                wp_nav_menu(
                                    array(
                                        'container' => '',
                                        'items_wrap' => '%3$s',
                                        'theme_location' => 'sociallive-primary-menu',
                                        'show_toggles' => true,
                                    )
                                );

                            }else{
                                
                                wp_list_pages(
                                    array(
                                        'match_menu_classes' => true,
                                        'show_sub_menu_icons' => false,
                                        'title_li' => false,
                                        'show_toggles' => true,
                                        'walker' => new SocialLive_Walker_Page(),
                                    )
                                );
                            } ?>

                </ul>
            </nav><!-- .primary-menu-wrapper -->
        </div>

        <?php if( has_nav_menu('sociallive-social-menu') ){ ?>

        <div id="social-nav-offcanvas" class="offcanvas-item offcanvas-social-navigation">

            <?php
                        wp_nav_menu(array(
                            'theme_location' => 'sociallive-social-menu',
                            'link_before' => '<span class="screen-reader-text">',
                            'link_after' => '</span>',
                            'container' => 'div',
                            'container_class' => 'social-menu',
                            'depth' => 1,
                        )); ?>

        </div>

        <?php } ?>

        <a href="javascript:void(0)" class="skip-link-menu-end"></a>

    </div>
</div>

<?php
    }

endif;

add_action( 'sociallive_before_footer_content_action','sociallive_content_offcanvas',30 );

if( !function_exists('sociallive_footer_content_info') ):

    /**
     * Footer Copyright Area
    **/
    function sociallive_footer_content_info(){

        $sociallive_default = sociallive_get_default_theme_options(); ?>
<div class="footer-credits">
    <div class="wrapper">
        <div class="wrapper-inner wrapper-inner-center">
            <div class="column column-6 column-md-12">
                <div class="footer-copyright">

                    <?php
                    $ed_footer_copyright = wp_kses_post(get_theme_mod('ed_footer_copyright', $sociallive_default['ed_footer_copyright']));
                    $footer_copyright_text = wp_kses_post(get_theme_mod('footer_copyright_text', $sociallive_default['footer_copyright_text']));

                    echo esc_html__('Copyright ', 'sociallive') . '&copy ' . absint(date('Y')) . ' <a href="' . esc_url(home_url('/')) . '" title="' . esc_attr(get_bloginfo('name', 'display')) . '" >' . esc_html(get_bloginfo('name', 'display')) . '.</a> ' . esc_html($footer_copyright_text);

                    if ($ed_footer_copyright) {

                        echo '<br>';
                        echo esc_html__('Theme: ', 'sociallive') . 'SocialLive ' . esc_html__('By ', 'sociallive') . '<a href="' . esc_url('https://www.themeinwp.com/theme/sociallive') . '"  title="' . esc_attr__('Themeinwp', 'sociallive') . '" target="_blank" rel="author"><span>' . esc_html__('Themeinwp. ', 'sociallive') . '</span></a>';

                        echo esc_html__('Powered by ', 'sociallive') . '<a href="' . esc_url('https://wordpress.org') . '" title="' . esc_attr__('WordPress', 'sociallive') . '" target="_blank"><span>' . esc_html__('WordPress.', 'sociallive') . '</span></a>';

                    } ?>

                </div>
            </div>
            <div class="column column-6 column-md-12">
                <div class="footer-credits-extracontent">
                    <?php if( has_nav_menu('sociallive-social-menu') ){ ?>

                        <div id="social-nav" class="social-navigation">

                            <?php
                            wp_nav_menu(array(
                                'theme_location' => 'sociallive-social-menu',
                                'link_before' => '<span class="screen-reader-text">',
                                'link_after' => '</span>',
                                'container' => 'div',
                                'container_class' => 'social-menu',
                                'depth' => 1,
                            )); ?>

                        </div>

                    <?php } ?>

                    <?php sociallive_footer_go_to_top(); ?>
                </div>
            </div>
        </div>
    </div>
</div>
<?php
    }

endif;

add_action( 'sociallive_copyright_content_action','sociallive_footer_content_info',20 );


if( !function_exists('sociallive_footer_go_to_top') ):

    // Scroll to Top render content
    function sociallive_footer_go_to_top(){ ?>

<a class="to-the-top" href="#site-header">
    <span class="to-the-top-long">
        <?php printf(esc_html__('To the top %s', 'sociallive'), '<span class="arrow" aria-hidden="true">&uarr;</span>'); ?>
    </span>
    <span class="to-the-top-short">
        <?php printf(esc_html__('Up %s', 'sociallive'), '<span class="arrow" aria-hidden="true">&uarr;</span>'); ?>
    </span>
</a>

<?php
    }

endif;

if( ! function_exists( 'sociallive_iframe_escape' ) ):
    
    /** Escape Iframe **/
    function sociallive_iframe_escape( $input ){

        $all_tags = array(
            'iframe'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'frameborder'=>array(),
                'allow'=>array(),
                'allowfullscreen'=>array(),
            ),
            'video'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'style'=>array(),
                'controls'=>array(),
            )
        );

        return wp_kses($input,$all_tags);
        
    }

endif;

if( !function_exists('sociallive_after_content_pagination') ):

    function sociallive_after_content_pagination($after_content){

        $pagination_single = wp_link_pages( array(
                    'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'sociallive' ),
                    'after'  => '</div>',
                    'echo' => false
                ) );

        $after_content =  $pagination_single.$after_content;

        return $after_content;

    }

endif;

if( !function_exists('sociallive_excerpt_content') ):

    function sociallive_excerpt_content(){ 

        $sociallive_default = sociallive_get_default_theme_options();
        $ed_post_excerpt = get_theme_mod( 'ed_post_excerpt',$sociallive_default['ed_post_excerpt'] );

        if( $ed_post_excerpt ){ ?>

<div class="entry-content entry-content-small">

    <?php
                if( has_excerpt() ){

                    the_excerpt();

                }else{

                    echo esc_html( wp_trim_words( get_the_content(), 25, '...' ) );

                } ?>

</div>

<?php }
    }

endif;


if ( ! function_exists( 'sociallive_svg_escape' ) ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function sociallive_svg_escape( $input ) {

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            $input,
            array(
                'svg'     => array(
                    'class'       => true,
                    'xmlns'       => true,
                    'width'       => true,
                    'height'      => true,
                    'viewbox'     => true,
                    'aria-hidden' => true,
                    'role'        => true,
                    'focusable'   => true,
                ),
                'path'    => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'd'         => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'points'    => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );

        if ( ! $svg ) {
            return false;
        }

        return $svg;

    }

endif;

/*
 * Check if post content has embed code.
 */
function sociallive_has_embed_code() {

    $content = get_the_content();

    $has_embed =false;

    preg_match  ('/<iframe(.+)\"/', $content, $matches);
    if (!empty($matches)) {
        return true;
    }

    preg_match  ('/<object(.+)\"/', $content, $matches);
    if (!empty($matches)) {
        return true;
    }

    preg_match  ('/<embed(.+)\"/', $content, $matches);
    if (!empty($matches)) {
        return true;
    }

    if (strpos($content, '[embed]') !== false) {
        return true;
    }

    preg_match  ('/<video(.+)\"/', $content, $matches);
    if (!empty($matches)) {
        return true;
    }
    
}
/**
 * Detect if post content has video embed.
 */
if ( ! function_exists( 'sociallive_has_embed' ) ) :

function sociallive_has_embed( $post_id = false ) {
    if( !$post_id )
        $post_id = get_the_ID();
    else
        $post_id = absint( $post_id );
    if( !$post_id )
        return false;
 
    $post_meta = get_post_custom_keys( $post_id );
    
    if (!empty($post_meta )) {
        foreach( $post_meta as $meta ) {
            if( '_oembed' != substr( trim( $meta ) , 0 , 7 ) )
                continue;
            return true;
        }
    }
    return false;
}

endif;

if ( ! function_exists( 'sociallive_comment_details' ) ):
    function sociallive_comment_details($comment, $args, $depth) {
        if ( 'div' === $args['style'] ) {
            $tag       = 'div';
            $add_below = 'comment';
        } else {
            $tag       = 'li';
            $add_below = 'div-comment';
        }?>
        <<?php echo $tag; ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?> id="comment-<?php comment_ID() ?>"><?php 
        if ( 'div' != $args['style'] ) { ?>
            <div id="div-comment-<?php comment_ID() ?>" class="comment-body"><?php
        } ?>
            <div class="comment-author vcard"><?php 
                if ( $args['avatar_size'] != 0 ) {
                    echo get_avatar( $comment, $args['avatar_size'] ); 
                } 
                printf( wp_kses( '<cite class="fn">%s</cite> <span class="says">says:</span>' ,'sociallive'), get_comment_author_link() ); ?>
                <?php 
                if ( $comment->comment_approved == '0' ) { ?>
                    <em class="comment-awaiting-moderation"><?php echo esc_html__( 'Your comment is awaiting moderation.','sociallive' ); ?></em><br/><?php 
                } ?>
                <div class="comment-meta commentmetadata">
                    <a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>"><?php
                        /* translators: 1: date, 2: time */
                        printf( 
                            esc_html__('%1$s at %2$s','sociallive' ), 
                            get_comment_date(),  
                            get_comment_time() 
                        ); ?>
                    </a><?php 
                    edit_comment_link( esc_html__( '(Edit)','sociallive' ), '  ', '' ); ?>
                </div>
            </div>
     
            <?php comment_text(); ?>
     
            <div class="reply"><?php 
                    comment_reply_link( 
                        array_merge( 
                            $args, 
                            array( 
                                'add_below' => $add_below, 
                                'depth'     => $depth, 
                                'max_depth' => $args['max_depth'] 
                            ) 
                        ) 
                    ); ?>
            </div><?php 
        if ( 'div' != $args['style'] ) : ?>
            </div><?php 
        endif;
    }
endif;