<?php
/**
 * SocialLive Theme Customizer
 *
 * @package SocialLive
 */

/** Sanitize Functions. **/
	require get_template_directory() . '/inc/customizer/default.php';

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
if (!function_exists('sociallive_customize_register')) :

function sociallive_customize_register( $wp_customize ) {

	require get_template_directory() . '/inc/customizer/custom-classes.php';
	require get_template_directory() . '/inc/customizer/sanitize.php';
	require get_template_directory() . '/inc/customizer/header.php';
	require get_template_directory() . '/inc/customizer/sidebar-filter-settings.php';
	require get_template_directory() . '/inc/customizer/homepage-banner-settings.php';
	require get_template_directory() . '/inc/customizer/pagination.php';
	require get_template_directory() . '/inc/customizer/post.php';
	require get_template_directory() . '/inc/customizer/single.php';
	require get_template_directory() . '/inc/customizer/footer.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	$wp_customize->remove_section('header_image');

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.header-titles .custom-logo-name',
			'render_callback' => 'sociallive_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'sociallive_customize_partial_blogdescription',
		) );
	}
	
	$sociallive_default = sociallive_get_default_theme_options();

	$wp_customize->add_setting('site_header_dark_logo',
		array(
			'default'           => '',
			'capability'        => 'edit_theme_options',
			'sanitize_callback' => 'sociallive_sanitize_image',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Image_Control($wp_customize, 'site_header_dark_logo',
			array(
				'label'       => esc_html__('Site Header Dark logo', 'sociallive'),
				'section'     => 'title_tagline',
			)
		)
	);


	$wp_customize->add_setting('logo_height_range',
	    array(
	        'default'           => $sociallive_default['logo_height_range'],
	        'capability'        => 'edit_theme_options',
	        'sanitize_callback' => 'sociallive_sanitize_number_range',
	    )
	);
	$wp_customize->add_control('logo_height_range',
	    array(
	        'label'       => esc_html__('Logo Width', 'sociallive'),
	        'description'       => esc_html__( 'Provide a range for the logo size, starting at a minimum of 200px and going up to a maximum of 80px, with increments of 2px.', 'sociallive' ),
	        'section'     => 'title_tagline',
	        'type'        => 'range',
	        'input_attrs' => array(
				           'min'   => 10,
				           'max'   => 100,
				           'step'   => 5,
			        	),
	    )
	);

	// Enable Disable Latest post.
	$wp_customize->add_setting('ed_latest_post',
	    array(
	        'default' => $sociallive_default['ed_latest_post'],
	        'capability' => 'edit_theme_options',
	        'sanitize_callback' => 'sociallive_sanitize_checkbox',
	    )
	);
	$wp_customize->add_control('ed_latest_post',
	    array(
	        'label' => esc_html__('Enable Latest Post Content', 'sociallive'),
	        'section' => 'static_front_page',
	        'type' => 'checkbox',
            'active_callback' 	=> 'sociallive_is_select_latest_post',
	    )

	);
	// Theme Options Panel.
	$wp_customize->add_panel( 'theme_option_panel',
		array(
			'title'      => esc_html__( 'Theme Options', 'sociallive' ),
			'priority'   => 150,
			'capability' => 'edit_theme_options',
		)
	);

	$wp_customize->add_panel( 'theme_general_settings',
		array(
			'title'      => esc_html__( 'General Settings', 'sociallive' ),
			'priority'   => 10,
			'capability' => 'edit_theme_options',
		)
	);


	// Register custom section types.
	$wp_customize->register_section_type( 'SocialLive_Customize_Section_Upsell' );

	// Register sections.
	$wp_customize->add_section(
		new SocialLive_Customize_Section_Upsell(
			$wp_customize,
			'theme_upsell',
			array(
				'title'    => esc_html__( 'SocialLive Pro', 'sociallive' ),
				'pro_text' => esc_html__( 'Purchase', 'sociallive' ),
				'pro_url'  => esc_url('https://www.themeinwp.com/theme/sociallive-pro/'),
				'priority'  => 1,
			)
		)
	);

}

endif;
add_action( 'customize_register', 'sociallive_customize_register' );

/**
 * Customizer Enqueue scripts and styles.
 */

if (!function_exists('sociallive_customizer_scripts')) :

    function sociallive_customizer_scripts(){   
    	
    	wp_enqueue_script('jquery-ui-button');
    	wp_enqueue_style('sociallive-customizer', get_template_directory_uri() . '/assets/lib/custom/css/customizer.css');
        wp_enqueue_script('sociallive-customizer', get_template_directory_uri() . '/assets/lib/custom/js/customizer.js', array('jquery','customize-controls'), '', 1);

        $sociallive_post_category_list = sociallive_post_category_list();

	    $cat_option = '';

	    if( $sociallive_post_category_list ){
		    foreach( $sociallive_post_category_list as $key => $cats ){
		    	$cat_option .= "<option value='". esc_attr( $key )."'>". esc_html( $cats )."</option>";
		    }
		}

        $ajax_nonce = wp_create_nonce('sociallive_ajax_nonce');
        wp_localize_script( 
		    'sociallive-customizer', 
		    'sociallive_customizer',
		    array(
		        'ajax_url'   => esc_url( admin_url( 'admin-ajax.php' ) ),
		        'ajax_nonce' => $ajax_nonce,
		     )
		);
    }

endif;

add_action('customize_controls_enqueue_scripts', 'sociallive_customizer_scripts');
add_action('customize_controls_init', 'sociallive_customizer_scripts');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */

if (!function_exists('sociallive_customize_partial_blogname')) :

	function sociallive_customize_partial_blogname() {
		bloginfo( 'name' );
	}
endif;

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */

if (!function_exists('sociallive_customize_partial_blogdescription')) :

	function sociallive_customize_partial_blogdescription() {
		bloginfo( 'description' );
	}

endif;


add_action('wp_ajax_sociallive_customizer_font_weight', 'sociallive_customizer_font_weight_callback');
add_action('wp_ajax_nopriv_sociallive_customizer_font_weight', 'sociallive_customizer_font_weight_callback');

// Recommendec Post Ajax Call Function.
function sociallive_customizer_font_weight_callback() {

    if ( isset( $_POST['_wpnonce'] ) && wp_verify_nonce( wp_unslash( $_POST['_wpnonce'] ), 'sociallive_ajax_nonce' ) && isset( $_POST['currentfont'] ) && sanitize_text_field( wp_unslash( $_POST['currentfont'] ) ) ) {

       $currentfont = sanitize_text_field( wp_unslash( $_POST['currentfont'] ) );
       $headings_fonts_property = SocialLive_Fonts::sociallive_get_fonts_property( $currentfont );

       foreach( $headings_fonts_property['weight'] as $key => $value ){
       		echo '<option value="'.esc_attr( $key ).'">'.esc_html( $value ).'</option>';
       }
    }
    wp_die();
}