<?php
/**
* Custom Functions.
*
* @package SocialLive
*/

if( !function_exists( 'sociallive_sanitize_single_pagination_layout' ) ) :

    // Sidebar Option Sanitize.
    function sociallive_sanitize_single_pagination_layout( $sociallive_input ){

        $sociallive_single_pagination = array( 'no-navigation','norma-navigation','ajax-next-post-load' );
        if( in_array( $sociallive_input,$sociallive_single_pagination ) ){

            return $sociallive_input;

        }

        return;

    }

endif;

if( !function_exists( 'sociallive_sanitize_archive_layout' ) ) :

    // Sidebar Option Sanitize.
    function sociallive_sanitize_archive_layout( $sociallive_input ){

        $sociallive_archive_option = array( 'default','full','grid' );
        if( in_array( $sociallive_input,$sociallive_archive_option ) ){

            return $sociallive_input;

        }

        return;

    }

endif;

if( !function_exists( 'sociallive_sanitize_header_layout' ) ) :

    // Sidebar Option Sanitize.
    function sociallive_sanitize_header_layout( $sociallive_input ){

        $sociallive_header_options = array( 'layout-1','layout-2','layout-3' );
        if( in_array( $sociallive_input,$sociallive_header_options ) ){

            return $sociallive_input;

        }

        return;

    }

endif;

if( !function_exists( 'sociallive_sanitize_single_post_layout' ) ) :

    // Single Layout Option Sanitize.
    function sociallive_sanitize_single_post_layout( $sociallive_input ){

        $sociallive_single_layout = array( 'layout-1','layout-2' );
        if( in_array( $sociallive_input,$sociallive_single_layout ) ){

            return $sociallive_input;

        }

        return;

    }

endif;

if ( ! function_exists( 'sociallive_sanitize_checkbox' ) ) :

	/**
	 * Sanitize checkbox.
	 */
	function sociallive_sanitize_checkbox( $sociallive_checked ) {

		return ( ( isset( $sociallive_checked ) && true === $sociallive_checked ) ? true : false );

	}

endif;


if ( ! function_exists( 'sociallive_sanitize_select' ) ) :

    /**
     * Sanitize select.
     */
    function sociallive_sanitize_select( $sociallive_input, $sociallive_setting ) {

        // Ensure input is a slug.
        $sociallive_input = sanitize_text_field( $sociallive_input );

        // Get list of choices from the control associated with the setting.
        $choices = $sociallive_setting->manager->get_control( $sociallive_setting->id )->choices;

        // If the input is a valid key, return it; otherwise, return the default.
        return ( array_key_exists( $sociallive_input, $choices ) ? $sociallive_input : $sociallive_setting->default );

    }

endif;

if ( ! function_exists( 'sociallive_sanitize_positive_integer' ) ) :

    /**
     * Sanitize positive integer.
     *
     * @since 1.0.0
     *
     * @param int                  $input Number to sanitize.
     * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
     * @return int Sanitized number; otherwise, the setting default.
     */
    function sociallive_sanitize_positive_integer( $input, $setting ) {

        $input = absint( $input );

        // If the input is an absolute integer, return it.
        // otherwise, return the default.
        return ( $input ? $input : $setting->default );

    }

endif;


if ( ! function_exists( 'sociallive_sanitize_number_range' ) ) :

    /**
     * Sanitize number range.
     *
     * @since 1.0.0
     *
     * @see absint() https://developer.wordpress.org/reference/functions/absint/
     *
     * @param int                  $input Number to check within the numeric range defined by the setting.
     * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
     * @return int|string The number, if it is zero or greater and falls within the defined range; otherwise, the setting default.
     */
    function sociallive_sanitize_number_range( $input, $setting ) {

        // Ensure input is an absolute integer.
        $input = absint( $input );

        // Get the input attributes associated with the setting.
        $atts = $setting->manager->get_control( $setting->id )->input_attrs;

        // Get min.
        $min = ( isset( $atts['min'] ) ? $atts['min'] : $input );

        // Get max.
        $max = ( isset( $atts['max'] ) ? $atts['max'] : $input );

        // Get Step.
        $step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );

        // If the input is within the valid range, return it; otherwise, return the default.
        return ( $min <= $input && $input <= $max && is_int( $input / $step ) ? $input : $setting->default );

    }

endif;


if ( ! function_exists( 'sociallive_sanitize_image' ) ) :

    /**
     * Sanitize image.
     *
     * @since 1.0.0
     *
     * @see wp_check_filetype() https://developer.wordpress.org/reference/functions/wp_check_filetype/
     *
     * @param string               $image Image filename.
     * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
     * @return string The image filename if the extension is allowed; otherwise, the setting default.
     */
    function sociallive_sanitize_image( $image, $setting ) {

        /**
         * Array of valid image file types.
         *
         * The array includes image mime types that are included in wp_get_mime_types().
        */
        $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon',
        );

        // Return an array with file extension and mime_type.
        $file = wp_check_filetype( $image, $mimes );

        // If $image has a valid mime_type, return it; otherwise, return the default.
        return ( $file['ext'] ? $image : $setting->default );

    }

endif;


