<?php
/**
 *
 * Pagination Functions
 *
 * @package SocialLive
 */

if( !function_exists('sociallive_archive_pagination_x') ):

    // Archive Page Navigation
    function sociallive_archive_pagination_x(){

        // Global Query
        if( is_front_page() ){

            $posts_per_page = absint( get_option('posts_per_page') );
            $paged_c = ( get_query_var( 'page' ) ) ? absint( get_query_var( 'page' ) ) : 1;
            $posts_args = array(
                'posts_per_page'        => $posts_per_page,
                'paged'                 => $paged_c,
            );
            $posts_qry = new WP_Query( $posts_args );
            $max = $posts_qry->max_num_pages;

        }else{
            global $wp_query;
            $max = $wp_query->max_num_pages;
            $paged_c = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;
        }

        $sociallive_default = sociallive_get_default_theme_options();
        $sociallive_pagination_layout = esc_html( get_theme_mod( 'sociallive_pagination_layout',$sociallive_default['sociallive_pagination_layout'] ) );
        $sociallive_pagination_load_more = esc_html__('Load More Posts','sociallive');
        $sociallive_pagination_no_more_posts = esc_html__('No More Posts','sociallive');

        if( $sociallive_pagination_layout == 'next-prev' ){

            the_posts_navigation([
                'prev_text'=>sociallive_the_theme_svg( 'arrow-left',$return = true ).'<span class="nav-link-label">'. __('Older posts','sociallive').'</span>',
                'next_text'=> '<span class="nav-link-label">'. __('Newer posts','sociallive').'</span>'.sociallive_the_theme_svg( 'arrow-right',$return = true ),
            ]);

        }elseif( $sociallive_pagination_layout == 'load-more' || $sociallive_pagination_layout == 'auto-load' ){ ?>

            <div class="theme-ajax-loadpost hide-no-js">

                <div style="display: none;" class="theme-loaded-content"></div>
                

                <?php if( $max > 1 ){ ?>

                    <button class="theme-loading-button theme-loading-style" href="javascript:void(0)">
                        <span style="display: none;" class="theme-loading-status"></span>
                        <span class="loading-text"><?php echo esc_html( $sociallive_pagination_load_more ); ?></span>
                    </button>

                <?php }else{ ?>

                    <button class="theme-loading-button theme-loading-style theme-no-posts" href="javascript:void(0)">
                        <span style="display: none;" class="theme-loading-status"></span>
                        <span class="loading-text"><?php echo esc_html( $sociallive_pagination_no_more_posts ); ?></span>
                    </button>

                <?php } ?>

            </div>

        <?php }else{

            the_posts_pagination();

        }
            
    }

endif;
add_action('sociallive_archive_pagination','sociallive_archive_pagination_x',20);