<?php
/**
 * Recent Post Widgets.
 *
 * @package SocialLive
 */
if (!function_exists('sociallive_recent_post_widgets')) :
    /**
     * Load widgets.
     *
     * @since 1.0.0
     */
    function sociallive_recent_post_widgets()
    {
        register_widget('SocialLive_Sidebar_Recent_Post_Widget');
    }
endif;
add_action('widgets_init', 'sociallive_recent_post_widgets');
// Recent Post widget
if (!class_exists('SocialLive_Sidebar_Recent_Post_Widget')) :
    /**
     * Recent Post.
     *
     * @since 1.0.0
     */
    class SocialLive_Sidebar_Recent_Post_Widget extends SocialLive_Widget_Base
    {
        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct()
        {
            $opts = array(
                'classname' => 'sociallive_recent_post_widget',
                'description' => esc_html__('Displays post form selected category specific for popular post in sidebars.', 'sociallive'),
                'customize_selective_refresh' => true,
            );
            $fields = array(
                'title' => array(
                    'label' => esc_html__('Title:', 'sociallive'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'post_category' => array(
                    'label' => esc_html__('Select Category:', 'sociallive'),
                    'type' => 'dropdown-taxonomies',
                    'show_option_all' => esc_html__('All Categories', 'sociallive'),
                ),
                'show_more' => array(
                    'label' => esc_html__('Enable show more:', 'sociallive'),
                    'type' => 'checkbox',
                    'default' => true,
                ),
                'enable_author_image' => array(
                    'label' => esc_html__('Enable Author Image:', 'sociallive'),
                    'type' => 'checkbox',
                    'default' => true,
                ),
                'post_number' => array(
                    'label' => esc_html__('Number of Posts:', 'sociallive'),
                    'type' => 'number',
                    'default' => 4,
                    'css' => 'max-width:60px;',
                    'min' => 1,
                    'max' => 5,
                ),
            );
            parent::__construct('SocialLive-popular-sidebar-layout', esc_html__('SocialLive: Recent Widget', 'sociallive'), $opts, array(), $fields);
        }

        /**
         * Outputs the content for the current widget instance.
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         * @since 1.0.0
         *
         */
        function widget($args, $instance)
        {
            $params = $this->get_params($instance);
            $theme_show_more = isset($params['show_more']) ? $params['show_more'] : '';
            echo $args['before_widget'];
            $home_section_title = esc_html($params['title']);
            $qargs = array(
                'posts_per_page' => esc_attr($params['post_number']),
                'no_found_rows' => true,
            );
            if (absint($params['post_category']) > 0) {
                $qargs['cat'] = absint($params['post_category']);
            }
            $recent_posts_query = new WP_Query($qargs);
            $count = 1;
            if ($recent_posts_query->have_posts()) : ?>
                <div class="theme-custom-widget custom-widget-recent">
                    <div class="wrapper">
                        <?php if (isset($params['title']) && $params['title']) { ?>
                            <div class="wrapper-inner">
                                <div class="column column-12">
                                    <header class="block-title-wrapper">
                                        <h3 class="theme-block-title theme-block-title-medium">
                                            <?php echo $home_section_title; ?>
                                        </h3>
                                    </header>
                                </div>
                            </div>
                        <?php } ?>

                        <div class="wrapper-inner">
                            <?php
                            while ($recent_posts_query->have_posts()) :
                                $recent_posts_query->the_post();
                                $slidet_to_show = $params['post_number'];
                                switch ($slidet_to_show) {
                                    case "1":
                                        $twp_data_bg_size = 'data-bg-large';
                                        $twp_column_num = 'column-12';
                                        break;
                                    case "2":
                                        $twp_data_bg_size = 'data-bg-medium';
                                        $twp_column_num = 'column-6';
                                        break;
                                    case "3":
                                        $twp_data_bg_size = 'data-bg-medium';
                                        $twp_column_num = 'column-4';
                                        break;
                                    case "4":
                                        $twp_data_bg_size = 'data-bg-small';
                                        $twp_column_num = 'column-3 column-sm-6';
                                        break;
                                    default:
                                        $twp_data_bg_size = 'data-bg-small';
                                        $twp_column_num = 'column-fifth';
                                }
                                ?>
                                <div class="column <?php echo $twp_column_num; ?> column-xs-12">
                                    <article id="theme-post-<?php the_ID(); ?>" <?php post_class('theme-post-article theme-post-recent'); ?>>
                                            <?php
                                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium_large');
                                            $featured_image = isset($featured_image[0]) ? $featured_image[0] : '';
                                            $featured_image_full = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
                                            $featured_image_full = isset($featured_image_full[0]) ? $featured_image_full[0] : '';
                                            $content = apply_filters('the_content', get_the_content());
                                            $video = false;
                                            $video_url = '';
                                            $video_url = sociallive_video_pop_up_url($content, $video, $video_url);

                                            if (has_post_thumbnail()) {
                                                ?>
                                                <div class="theme-media-panel">
                                                    <?php if (!empty($video_url)) { ?>
                                                        <a class="theme-media-link" href="<?php echo esc_url($video_url); ?>" data-title="<?php the_title_attribute(); ?>" data-caption="<?php the_excerpt(); ?>">
                                                            <span class="data-bg thumb-overlay img-hover-shine <?php echo $twp_data_bg_size; ?>" data-background="<?php echo esc_url($featured_image); ?>">
                                                                <span id="video-icon-holder">
                                                                    <span id="media-video-icon"></span>
                                                                </span>
                                                            </span>
                                                        </a>
                                                    <?php } else { ?>
                                                        <a class="popup-image-link" href="<?php echo esc_url($featured_image_full); ?>" data-title="<?php the_title_attribute(); ?>" data-caption="<?php the_excerpt(); ?>">
                                                            <span class="data-bg thumb-overlay img-hover-shine <?php echo $twp_data_bg_size; ?>" data-background="<?php echo esc_url($featured_image); ?>"></span>
                                                        </a>
                                                    <?php } ?>
                                                </div>
                                            <?php } ?>

                                        <div class="article-content">
                                            <?php
                                            $enable_author_image = isset($params['enable_author_image']);
                                            if ($enable_author_image) { ?>
                                                <div class="article-content-left">
                                                    <?php $author_img = get_avatar(get_the_author_meta('ID'), 60, '', '', array('class' => 'avatar-img')); ?>
                                                    <div class="theme-author-image">
                                                        <?php echo wp_kses_post($author_img); ?>
                                                    </div>
                                                </div>
                                            <?php } ?>
                                            <div class="article-content-right">
                                                <header class="entry-header">
                                                    <h3 class="entry-title entry-title-small">
                                                        <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark" title="<?php the_title_attribute(); ?>">
                                                            <?php the_title(); ?>
                                                        </a>
                                                    </h3>
                                                </header>
                                                <div class="entry-meta">
                                                    <?php sociallive_posted_by(); ?>
                                                    <?php sociallive_posted_on(); ?>
                                                    
                                                </div>
                                            </div>
                                        </div>
                                    </article>
                                </div>
                                <?php
                                $count++;
                            endwhile; ?>
                        </div>
                    </div>
                    <?php if ($theme_show_more == 'true' || empty($params['post_category'])) { ?>
                        <div class="wrapper">
                            <footer class="block-footer-wrapper">
                                <hr>
                                <a href="<?php echo esc_url(get_category_link($params['post_category'])); ?>"
                                   class="block-footer-link">
                                <span class="block-footer-label">
                                    <?php echo esc_html__('Show More', 'sociallive'); ?>
                                </span>
                                    <span class="block-footer-icon">
                                    <?php sociallive_the_theme_svg('chevron-down'); ?>
                                </span>
                                </a>
                            </footer>
                        </div>
                    <?php } ?>
                </div>
                <?php wp_reset_postdata();
            endif;
            echo $args['after_widget'];
        }
    }
endif;