<?php
/**
 * Recent Post Widgets.
 *
 * @package Sociallive
 */
if (!function_exists('sociallive_recent_post_list_widgets')) :
    /**
     * Load widgets.
     *
     * @since 1.0.0
     */
    function sociallive_recent_post_list_widgets()
    {
        register_widget('Sociallive_Sidebar_Recent_Post_List_Widget');
    }
endif;
add_action('widgets_init', 'sociallive_recent_post_list_widgets');
// Recent Post widget
if (!class_exists('Sociallive_Sidebar_Recent_Post_List_Widget')) :
    /**
     * Recent Post.
     *
     * @since 1.0.0
     */
    class Sociallive_Sidebar_Recent_Post_List_Widget extends Sociallive_Widget_Base
    {
        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct()
        {
            $opts = array(
                'classname' => 'sociallive_recent_post_list_widget',
                'description' => esc_html__('Displays post form selected category specific for popular post in sidebars.', 'sociallive'),
                'customize_selective_refresh' => true,
            );
            $fields = array(
                'title' => array(
                    'label' => esc_html__('Title:', 'sociallive'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'post_category' => array(
                    'label' => esc_html__('Select Category:', 'sociallive'),
                    'type' => 'dropdown-taxonomies',
                    'show_option_all' => esc_html__('All Categories', 'sociallive'),
                ),
                'post_number' => array(
                    'label' => esc_html__('Number of Posts:', 'sociallive'),
                    'type' => 'number',
                    'default' => 10,
                    'css' => 'max-width:60px;',
                    'min' => 1,
                    'max' => 15,
                ),
            );
            parent::__construct('sociallive-popular-sidebar-list-layout', esc_html__('Sociallive: Single Sidebar Recent Widget', 'sociallive'), $opts, array(), $fields);
        }

        /**
         * Outputs the content for the current widget instance.
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         * @since 1.0.0
         *
         */
        function widget($args, $instance)
        {
            $params = $this->get_params($instance);
            $theme_show_more = isset($params['show_more']) ? $params['show_more'] : '';
            echo $args['before_widget'];
            $home_section_title = esc_html($params['title']);
            $qargs = array(
                'posts_per_page' => esc_attr($params['post_number']),
                'no_found_rows' => true,
            );
            if (absint($params['post_category']) > 0) {
                $qargs['cat'] = absint($params['post_category']);
            }
            $recent_posts_query = new WP_Query($qargs);
            $count = 1;
            if ($recent_posts_query->have_posts()) : ?>
                <div class="theme-sidebar-widget sidebar-widget-recent">

                    <?php if (isset($params['title']) && $params['title']) { ?>
                        <header class="block-title-wrapper">
                            <h2 class="theme-block-title theme-block-title-medium">
                                <?php echo $home_section_title; ?>
                            </h2>
                        </header>
                    <?php } ?>
                    <div class="custom-widget-list-block">

                        <?php
                        while ($recent_posts_query->have_posts()) :
                            $recent_posts_query->the_post();
                            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium_large');
                            $featured_image = isset($featured_image[0]) ? $featured_image[0] : '';
                            ?>
                            <div class="list-block">
                                <div class="wrapper-inner">
                                    <div class="column column-5">
                                        <div class="data-bg data-bg-thumbnail" data-background='<?php echo esc_url($featured_image); ?>'></div>
                                    </div>

                                    <div class="column column-7">
                                        <h3 class="entry-title entry-title-small line-clamp-3">
                                            <a href="<?php the_permalink(); ?>">
                                                <?php the_title(); ?>
                                            </a>
                                        </h3>
                                        <div class="entry-meta">
                                            <?php sociallive_posted_by(); ?>
                                            <?php sociallive_posted_on(); ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php
                            $count++;
                        endwhile; ?>

                    </div>

                </div>
                <?php wp_reset_postdata();
            endif;
            echo $args['after_widget'];
        }
    }
endif;